@@ -1,27 +1,41 @@
 #-------Main Package Settings-----------#
 import sys
 
-name = 'Cheetah'
-from cheetah.Version import Version as version
-maintainer = "R. Tyler Ballance"
+# Cheetah3 has already been taken at PyPI,
+# CheetahTemplate3 seems to be too long.
+name = 'Cheetah3'
+from Cheetah.Version import Version as version
+description = "Cheetah is a template engine and code generation tool"
+license = "MIT"
 author = "Tavis Rudd"
-author_email = "cheetahtemplate-discuss@lists.sf.net"
-url = "http://www.cheetahtemplate.org/"
+author_email = "tavis@damnsimple.com"
+maintainer = "Oleg Broytman"
+maintainer_email = "phd@phdru.name"
+url = "http://cheetahtemplate.org/"
+dev_tag = ""
+download_url = "https://pypi.python.org/pypi/%s/%s%s" % (name, version, dev_tag)
+del dev_tag
 packages = ['Cheetah',
-            'Cheetah.Macros',            
+            'Cheetah.Macros',
             'Cheetah.Templates',
             'Cheetah.Tests',
             'Cheetah.Tools',
             'Cheetah.Utils',
             ]
 classifiers = [line.strip() for line in '''\
-  #Development Status :: 4 - Beta
   Development Status :: 5 - Production/Stable
   Intended Audience :: Developers
   Intended Audience :: System Administrators
   License :: OSI Approved :: MIT License
   Operating System :: OS Independent
   Programming Language :: Python
+  Programming Language :: Python :: 2
+  Programming Language :: Python :: 2.7
+  Programming Language :: Python :: 3
+  Programming Language :: Python :: 3.3
+  Programming Language :: Python :: 3.4
+  Programming Language :: Python :: 3.5
+  Programming Language :: Python :: 3.6
   Topic :: Internet :: WWW/HTTP
   Topic :: Internet :: WWW/HTTP :: Dynamic Content
   Topic :: Internet :: WWW/HTTP :: Site Management
@@ -30,21 +44,24 @@ classifiers = [line.strip() for line in '''\
   Topic :: Software Development :: User Interfaces
   Topic :: Text Processing'''.splitlines() if not line.strip().startswith('#')]
 
-package_dir = {'Cheetah':'cheetah'}
+from Cheetah.compat import PY2
+if PY2:
+    del line
+del PY2  # Hide it from setup()
 
 import os
 import os.path
 from distutils.core import Extension
 
 ext_modules=[
-             Extension("Cheetah._namemapper", 
-                        [os.path.join('cheetah', 'c', '_namemapper.c')]),
-           #  Extension("Cheetah._verifytype", 
-           #             [os.path.join('cheetah', 'c', '_verifytype.c')]),
-           #  Extension("Cheetah._filters", 
-           #             [os.path.join('cheetah', 'c', '_filters.c')]),
+             Extension("Cheetah._namemapper",
+                        [os.path.join('Cheetah', 'c', '_namemapper.c')]),
+           #  Extension("Cheetah._verifytype",
+           #             [os.path.join('Cheetah', 'c', '_verifytype.c')]),
+           #  Extension("Cheetah._filters",
+           #             [os.path.join('Cheetah', 'c', '_filters.c')]),
            #  Extension('Cheetah._template',
-           #             [os.path.join('cheetah', 'c', '_template.c')]),
+           #             [os.path.join('Cheetah', 'c', '_template.c')]),
              ]
 
 ## Data Files and Scripts
@@ -53,14 +70,11 @@ scripts = ('bin/cheetah-compile',
            'bin/cheetah-analyze',
         )
 
-data_files = ['recursive: cheetah *.tmpl *.txt LICENSE README TODO CHANGES',]
+data_files = ['recursive: Cheetah *.tmpl *.txt *.rst LICENSE README.rst TODO']
 
 if not os.getenv('CHEETAH_INSTALL_WITHOUT_SETUPTOOLS'):
     try:
         from setuptools import setup
-        install_requires = [
-                "Markdown >= 2.0.1",
-        ]
         if sys.platform == 'win32':
             # use 'entry_points' instead of 'scripts'
             del scripts
@@ -71,33 +85,31 @@ if not os.getenv('CHEETAH_INSTALL_WITHOUT_SETUPTOOLS'):
                 ]
         }
     except ImportError:
-        print('Not using setuptools, so we cannot install the Markdown dependency')
+        pass
 
-
-description = "Cheetah is a template engine and code generation tool."
-
-long_description = '''Cheetah is an open source template engine and code generation tool.
+long_description = '''\
+Cheetah3 is a free (BSD-style) and open source template engine and code
+generation tool.
 
 It can be used standalone or combined with other tools and frameworks. Web
 development is its principle use, but Cheetah is very flexible and is also being
 used to generate C++ game code, Java, sql, form emails and even Python code.
 
+It's a fork of the original CheetahTemplate library.
+
 Documentation
 ================================================================================
 For a high-level introduction to Cheetah please refer to the User\'s Guide
-at http://www.cheetahtemplate.org/learn.html
-
-Mailing list
-================================================================================
-cheetahtemplate-discuss@lists.sourceforge.net
-Subscribe at http://lists.sourceforge.net/lists/listinfo/cheetahtemplate-discuss
+at http://cheetahtemplate.org/users_guide/index.html
 
 Credits
 ================================================================================
-http://www.cheetahtemplate.org/credits.html
+http://cheetahtemplate.org/authors.html
+
+https://github.com/CheetahTemplate3/cheetah3/blob/master/LICENSE
 
 Recent Changes
 ================================================================================
-See http://www.cheetahtemplate.org/CHANGES.txt for full details
+See http://cheetahtemplate.org/news.html for full details
 
 '''
