@@ -1,48 +1,58 @@
-#!/usr/bin/env python
-# $Id: SetupTools.py,v 1.7 2005/08/17 18:45:21 tavis_rudd Exp $
-"""Some tools for extending and working with distutils
-
-CREDITS: This module borrows code and ideas from M.A. Lemburg's excellent setup
-tools for the mxBase package.
-
-"""
-
-__author__ = "Tavis Rudd <tavis@damnsimple.com>"
-__version__ = "$Revision: 1.7 $"[11:-2]
-
-##################################################
-## DEPENDENCIES ##
+from glob import glob
+import os
+import os.path
+import sys
 
 from distutils.core import setup
-## this bit is experimental:
-#try:
-#    # use http://peak.telecommunity.com/DevCenter/setuptools if it's installed
-#    # requires Py >=2.3
-#    from setuptools import setup
-#except ImportError:   
-#    from distutils.core import setup
+if not os.getenv('CHEETAH_INSTALL_WITHOUT_SETUPTOOLS'):
+    try:
+        from setuptools import setup
+    except ImportError:
+        from distutils.core import setup
 
 from distutils.core import Command
+from distutils.command.build_ext import build_ext
 from distutils.command.install_data import install_data
-
-import os
-from os import listdir
-import os.path
-from os.path import exists, isdir, isfile, join, splitext
-
-import types
-import glob
-import string
-import traceback
+from distutils.errors import CCompilerError, DistutilsExecError, \
+    DistutilsPlatformError
 
 #imports from Cheetah ...
-from src.FileUtils import findFiles
+from Cheetah.FileUtils import findFiles
+from Cheetah.compat import string_type
+
+if sys.platform == 'win32':
+   # 2.6's distutils.msvc9compiler can raise an IOError when failing to
+   # find the compiler
+   ext_errors = (CCompilerError, DistutilsExecError, DistutilsPlatformError,
+                 IOError)
+else:
+   ext_errors = (CCompilerError, DistutilsExecError, DistutilsPlatformError)
 
 ##################################################
 ## CLASSES ##
-   
+
+class BuildFailed(Exception):
+    pass
+
+class mod_build_ext(build_ext):
+    """A modified version of the distutils build_ext command that raises an
+    exception when building of the extension fails.
+    """
+
+    def run(self):
+        try:
+            build_ext.run(self)
+        except DistutilsPlatformError as x:
+            raise BuildFailed(x)
+
+    def build_extension(self, ext):
+        try:
+            build_ext.build_extension(self, ext)
+        except ext_errors as x:
+            raise BuildFailed(x)
+
+
 class mod_install_data(install_data):
-    
     """A modified version of the disutils install_data command that allows data
     files to be included directly in the installed Python package tree.
     """
@@ -60,12 +70,12 @@ class mod_install_data(install_data):
         if not self.dry_run:
             self.mkpath(self.install_dir)
         data_files = self.get_inputs()
-        
+
         for entry in data_files:
-            if type(entry) != types.StringType:
-                raise ValueError, 'The entries in "data_files" must be strings'
-            
-            entry = string.join(string.split(entry, '/'), os.sep)
+            if not isinstance(entry, string_type):
+                raise ValueError('The entries in "data_files" must be strings')
+
+            entry = os.sep.join(entry.split('/'))
             # entry is a filename or glob pattern
             if entry.startswith('recursive:'):
                 entry = entry[len('recursive:'):]
@@ -73,8 +83,8 @@ class mod_install_data(install_data):
                 globPatterns = entry.split()[1:]
                 filenames = findFiles(dir, globPatterns)
             else:
-                filenames = glob.glob(entry)
-            
+                filenames = glob(entry)
+
             for filename in filenames:
                 ## generate the dstPath from the filename
                 # - deal with 'package_dir' translations
@@ -101,12 +111,11 @@ class mod_install_data(install_data):
                 else:
                     outfile = dstPath
                 self.outfiles.append(outfile)
-        
+
 ##################################################
 ## FUNCTIONS ##
 
 def run_setup(configurations):
-
     """ Run distutils setup.
 
         The parameters passed to setup() are extracted from the list of modules,
@@ -120,25 +129,38 @@ def run_setup(configurations):
     """
     # Build parameter dictionary
     kws = {}
+    newkws = {}
     for configuration in configurations:
         kws.update(vars(configuration))
     for name, value in kws.items():
-        if name[:1] == '_' or \
-           type(value) not in (types.StringType,
-                               types.ListType,
-                               types.TupleType,
-                               types.DictType,
-                               types.IntType,
-                               ):
-            del kws[name]
+        if name[:1] == '_':
+            continue
+        if not isinstance(value, (string_type, list, tuple, dict, int)):
+            continue
+        newkws[name] = value
+    kws = newkws
 
     # Add setup extensions
     cmdclasses = {
+        'build_ext': mod_build_ext,
         'install_data': mod_install_data,
         }
 
     kws['cmdclass'] = cmdclasses
 
     # Invoke distutils setup
-    apply(setup, (), kws)
+    try:
+        setup(**kws)
+    except BuildFailed as x:
+        print("One or more C extensions failed to build.")
+        print("Details: %s" % x)
+        if os.environ.get('CHEETAH_C_EXTENSIONS_REQUIRED'):
+            raise x
+        print("Retrying without C extensions enabled.")
 
+        del kws['ext_modules']
+        setup(**kws)
+
+        print("One or more C extensions failed to build.")
+        print("Performance enhancements will not be available.")
+        print("Pure Python installation succeeded.")
